@@ -1,9 +1,17 @@
 from overrides.enforce import EnforceOverrides
-from overrides.final import final
+import sys
+
+if sys.version_info < (3, 11):
+    from overrides.final import final
+else:
+    from typing import final
 from overrides.overrides import __VERSION__, overrides
 
+override = overrides
+
 __all__ = [
     "__VERSION__",
+    "override",
     "overrides",
     "final",
     "EnforceOverrides",
